You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@nifi.apache.org by al...@apache.org on 2016/09/26 15:43:54 UTC

nifi git commit: NIFI-2796: - Fixing incorrect documentation for the cluster summary endpoint.

Repository: nifi
Updated Branches:
  refs/heads/master be85d9ddf -> 1b88552b4


NIFI-2796:
- Fixing incorrect documentation for the cluster summary endpoint.

This closes #1063.

Signed-off-by: Aldrin Piri <al...@apache.org>


Project: http://git-wip-us.apache.org/repos/asf/nifi/repo
Commit: http://git-wip-us.apache.org/repos/asf/nifi/commit/1b88552b
Tree: http://git-wip-us.apache.org/repos/asf/nifi/tree/1b88552b
Diff: http://git-wip-us.apache.org/repos/asf/nifi/diff/1b88552b

Branch: refs/heads/master
Commit: 1b88552b4677ceb1dfef0119c9c5a0306761ec95
Parents: be85d9d
Author: Matt Gilman <ma...@gmail.com>
Authored: Mon Sep 26 10:19:54 2016 -0400
Committer: Aldrin Piri <al...@apache.org>
Committed: Mon Sep 26 11:43:33 2016 -0400

----------------------------------------------------------------------
 .../org/apache/nifi/web/api/entity/ClusteSummaryEntity.java  | 2 +-
 .../src/main/java/org/apache/nifi/web/api/FlowResource.java  | 8 ++++----
 2 files changed, 5 insertions(+), 5 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/nifi/blob/1b88552b/nifi-nar-bundles/nifi-framework-bundle/nifi-framework/nifi-client-dto/src/main/java/org/apache/nifi/web/api/entity/ClusteSummaryEntity.java
----------------------------------------------------------------------
diff --git a/nifi-nar-bundles/nifi-framework-bundle/nifi-framework/nifi-client-dto/src/main/java/org/apache/nifi/web/api/entity/ClusteSummaryEntity.java b/nifi-nar-bundles/nifi-framework-bundle/nifi-framework/nifi-client-dto/src/main/java/org/apache/nifi/web/api/entity/ClusteSummaryEntity.java
index f3f4c34..d263120 100644
--- a/nifi-nar-bundles/nifi-framework-bundle/nifi-framework/nifi-client-dto/src/main/java/org/apache/nifi/web/api/entity/ClusteSummaryEntity.java
+++ b/nifi-nar-bundles/nifi-framework-bundle/nifi-framework/nifi-client-dto/src/main/java/org/apache/nifi/web/api/entity/ClusteSummaryEntity.java
@@ -23,7 +23,7 @@ import javax.xml.bind.annotation.XmlRootElement;
 /**
  * A serialized representation of this class can be placed in the entity body of a request or response to or from the API. This particular entity holds a reference to a ClusterSummaryDTO.
  */
-@XmlRootElement(name = "controllerStatusEntity")
+@XmlRootElement(name = "clusterSummaryEntity")
 public class ClusteSummaryEntity extends Entity {
 
     private ClusterSummaryDTO clusterSummary;

http://git-wip-us.apache.org/repos/asf/nifi/blob/1b88552b/nifi-nar-bundles/nifi-framework-bundle/nifi-framework/nifi-web/nifi-web-api/src/main/java/org/apache/nifi/web/api/FlowResource.java
----------------------------------------------------------------------
diff --git a/nifi-nar-bundles/nifi-framework-bundle/nifi-framework/nifi-web/nifi-web-api/src/main/java/org/apache/nifi/web/api/FlowResource.java b/nifi-nar-bundles/nifi-framework-bundle/nifi-framework/nifi-web/nifi-web-api/src/main/java/org/apache/nifi/web/api/FlowResource.java
index dd5a220..c97bb71 100644
--- a/nifi-nar-bundles/nifi-framework-bundle/nifi-framework/nifi-web/nifi-web-api/src/main/java/org/apache/nifi/web/api/FlowResource.java
+++ b/nifi-nar-bundles/nifi-framework-bundle/nifi-framework/nifi-web/nifi-web-api/src/main/java/org/apache/nifi/web/api/FlowResource.java
@@ -759,9 +759,9 @@ public class FlowResource extends ApplicationResource {
     }
 
     /**
      * Retrieves the status for this NiFi.
      *
-     * @return A controllerStatusEntity.
+     * @return A clusterSummaryEntity.
      * @throws InterruptedException if interrupted
      */
     @GET
@@ -769,8 +769,8 @@ public class FlowResource extends ApplicationResource {
     @Produces(MediaType.APPLICATION_JSON)
     @Path("cluster/summary")
     @ApiOperation(
-            value = "Gets the current status of this NiFi",
-            response = ControllerStatusEntity.class,
+            value = "The cluster summary for this NiFi",
+            response = ClusteSummaryEntity.class,
             authorizations = {
                     @Authorization(value = "Read - /flow", type = "")
             }
@@ -759,9 +759,9 @@ public class FlowResource extends ApplicationResource {
 
     /**
-     * Retrieves the status for this NiFi.
+     * Retrieves the cluster summary for this NiFi.
      *